@@ -267,6 +267,7 @@ class CheckBoxClient(BaseCheckBoxClient):
     def create_service_receipt(
         self,
         payment: Dict[str, Any],
+        id: Optional[str] = None,
         fiscal_code: Optional[str] = None,
         fiscal_date: Optional[datetime.datetime] = None,
         relax: int = DEFAULT_REQUESTS_RELAX,
@@ -275,7 +276,7 @@ class CheckBoxClient(BaseCheckBoxClient):
     ):
         receipt = self(
             receipts.CreateServiceReceipt(
-                payment=payment, fiscal_code=fiscal_code, fiscal_date=fiscal_date
+                payment=payment, id=id, fiscal_code=fiscal_code, fiscal_date=fiscal_date
             ),
             storage=storage,
         )
